# Sientia Log Library
Library for users to log information through SIENTIA™ <br />

Documentation for the library can be found [here](https://aignosi.github.io/sientia-log-library/) (Work in Progress)
